@@ -1,13 +1,14 @@
 # Copyright (c) Metakernel Development Team.
 # Distributed under the terms of the Modified BSD License.
 
-from metakernel import Magic
 from IPython.display import Latex
 
-class LatexMagic(Magic):
+from metakernel import Magic
 
-    def line_latex(self, text):
-        """
+
+class LatexMagic(Magic):
+    def line_latex(self, text) -> None:
+        r"""
         %latex TEXT - display text as LaTeX
 
         This line magic will display the TEXT on the line as LaTeX.
@@ -19,14 +20,14 @@ class LatexMagic(Magic):
         latex = Latex(text)
         self.kernel.Display(latex)
 
-    def cell_latex(self):
-        """
+    def cell_latex(self) -> None:
+        r"""
         %%latex - display contents of cell as LaTeX
 
         This cell magic will display the TEXT in the cell as LaTeX.
 
         Example:
-            %%latex 
+            %%latex
             $x_1 = \dfrac{a}{b}$
 
             $x_2 = a^{n - 1}$
@@ -35,5 +36,6 @@ class LatexMagic(Magic):
         self.kernel.Display(latex)
         self.evaluate = False
 
-def register_magics(kernel):
+
+def register_magics(kernel) -> None:
     kernel.register_magics(LatexMagic)
